package net.rumati.ezsql;

import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.Array;
import java.sql.Blob;
import java.sql.Clob;
import java.sql.Date;
import java.sql.NClob;
import java.sql.Ref;
import java.sql.ResultSet;
import java.sql.RowId;
import java.sql.SQLException;
import java.sql.SQLXML;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Calendar;
import java.util.Map;

/**
 * This class provides read access to a single column in a single row of a result set. It allows developers
 * to give only the access required to untrusted code that needs to read columns from result set in a certain way.
 * All methods represent the similarly named methods in the {@link ResultSet} class.
 * @author jesse
 */
public abstract class Column
{
    protected final Row row;
    
    Column(Row r)
    {
        this.row = r;
    }

    public static final Column fromIndex(ResultSet rs, int columnIndex)
    {
        return new ColumnByIndex(new Row(rs), columnIndex);
    }

    public static final Column fromLabel(ResultSet rs, String columnLabel)
    {
        return new ColumnByLabel(new Row(rs), columnLabel);
    }

    public static final Column fromIndex(Row r, int columnIndex)
    {
        return new ColumnByIndex(r, columnIndex);
    }

    public static final Column fromLabel(Row r, String columnLabel)
    {
        return new ColumnByLabel(r, columnLabel);
    }

    public final boolean wasNull() throws SQLException
    {
        return row.wasNull();
    }
    
    public abstract Boolean getNullableBoolean() throws SQLException;
    public abstract Byte getNullableByte() throws SQLException;
    public abstract Double getNullableDouble() throws SQLException;
    public abstract Float getNullableFloat() throws SQLException;
    public abstract Integer getNullableInt() throws SQLException;
    public abstract Long getNullableLong() throws SQLException;
    public abstract Short getNullableShort() throws SQLException;

    public abstract Array getArray() throws SQLException;
    public abstract InputStream getAsciiStream() throws SQLException;
    public abstract BigDecimal getBigDecimal() throws SQLException;
    public abstract InputStream getBinaryStream() throws SQLException;
    public abstract Blob getBlob() throws SQLException;
    public abstract boolean getBoolean() throws SQLException;
    public abstract byte getByte() throws SQLException;
    public abstract byte[] getBytes() throws SQLException;
    public abstract Reader getCharacterStream() throws SQLException;
    public abstract Clob getClob() throws SQLException;
    public abstract Date getDate() throws SQLException;
    public abstract Date getDate(Calendar cal) throws SQLException;
    public abstract double getDouble() throws SQLException;
    public abstract float getFloat() throws SQLException;
    public abstract int getInt() throws SQLException;
    public abstract long getLong() throws SQLException;
    public abstract Reader getNCharacterStream() throws SQLException;
    public abstract NClob getNClob() throws SQLException;
    public abstract String getNString() throws SQLException;
    public abstract Object getObject() throws SQLException;
    public abstract Object getObject(Map<String, Class<?>> map) throws SQLException;
    public abstract Ref getRef() throws SQLException;
    public abstract RowId getRowId() throws SQLException;
    public abstract SQLXML getSQLXML() throws SQLException;
    public abstract short getShort() throws SQLException;
    public abstract String getString() throws SQLException;
    public abstract Time getTime() throws SQLException;
    public abstract Time getTime(Calendar cal) throws SQLException;
    public abstract Timestamp getTimestamp() throws SQLException;
    public abstract Timestamp getTimestamp(Calendar cal) throws SQLException;
    public abstract URL getURL() throws SQLException;
}
