package net.rumati.ezsql;

import java.sql.SQLException;
import java.util.List;
import net.rumati.ezsql.conn.ConnectionFactory;

public class EZSQLDatabase
{
    private final ConnectionFactory connectionFactory;

    public EZSQLDatabase(ConnectionFactory connectionFactory)
    {
        this.connectionFactory = connectionFactory;
    }

    public int executeUpdateSQL(String sql) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.executeUpdateSQL(sql);
        }finally{
            conn.close();
        }
    }

    public int executeUpdateSQL(String sql, ParameterSetter parameter) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.executeUpdateSQL(sql, parameter);
        }finally{
            conn.close();
        }
    }

    public int executeUpdateSQL(String sql, ParameterSetter[] parameters) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.executeUpdateSQL(sql, parameters);
        }finally{
            conn.close();
        }
    }

    public int executeUpdateSQL(String sql, final List<ParameterSetter> parameters)
        throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.executeUpdateSQL(sql, parameters);
        }finally{
            conn.close();
        }
    }

    public <T> T withResultSet(String sql, final ResultSetHandler<T> handler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.withResultSet(sql, handler);
        }finally{
            conn.close();
        }
    }

    public <T> T withResultSet(String sql, ParameterSetter parameter, final ResultSetHandler<T> handler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.withResultSet(sql, parameter, handler);
        }finally{
            conn.close();
        }
    }

    public <T> T withResultSet(String sql, ParameterSetter[] parameters, ResultSetHandler<T> handler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.withResultSet(sql, parameters, handler);
        }finally{
            conn.close();
        }
    }

    public <T> T withResultSet(String sql, final List<ParameterSetter> parameters, final ResultSetHandler<T> handler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.withResultSet(sql, parameters, handler);
        }finally{
            conn.close();
        }
    }

    public <T> List<T> getAllResults(String sql, RowHandler<T> rowHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getAllResults(sql, rowHandler);
        }finally{
            conn.close();
        }
    }

    public <T> List<T> getAllResults(String sql, ParameterSetter parameter, RowHandler<T> rowHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getAllResults(sql, parameter, rowHandler);
        }finally{
            conn.close();
        }
    }

    public <T> List<T> getAllResults(String sql, ParameterSetter[] parameters, RowHandler<T> rowHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getAllResults(sql, parameters, rowHandler);
        }finally{
            conn.close();
        }
    }

    public <T> List<T> getAllResults(String sql, List<ParameterSetter> parameters, RowHandler<T> rowHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getAllResults(sql, parameters, rowHandler);
        }finally{
            conn.close();
        }
    }

    public <T> T getFirstResult(String sql, RowHandler<T> rowHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getFirstResult(sql, rowHandler);
        }finally{
            conn.close();
        }
    }

    public <T> T getFirstResult(String sql, ParameterSetter parameter, RowHandler<T> rowHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getFirstResult(sql, parameter, rowHandler);
        }finally{
            conn.close();
        }
    }

    public <T> T getFirstResult(String sql, ParameterSetter[] parameters, RowHandler<T> rowHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getFirstResult(sql, parameters, rowHandler);
        }finally{
            conn.close();
        }
    }

    public <T> T getFirstResult(String sql, List<ParameterSetter> parameters, RowHandler<T> rowHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getFirstResult(sql, parameters, rowHandler);
        }finally{
            conn.close();
        }
    }

    public <T> T getOneColumn(String sql, final ColumnHandler<T> columnHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneColumn(sql, columnHandler);
        }finally{
            conn.close();
        }
    }

    public <T> T getOneColumn(String sql, ParameterSetter parameter, final ColumnHandler<T> columnHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneColumn(sql, parameter, columnHandler);
        }finally{
            conn.close();
        }
    }

    public <T> T getOneColumn(String sql, ParameterSetter[] parameters, final ColumnHandler<T> columnHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneColumn(sql, parameters, columnHandler);
        }finally{
            conn.close();
        }
    }

    public <T> T getOneColumn(String sql, List<ParameterSetter> parameters, final ColumnHandler<T> columnHandler) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneColumn(sql, parameters, columnHandler);
        }finally{
            conn.close();
        }
    }

    public String getOneString(String sql) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneString(sql);
        }finally{
            conn.close();
        }
    }

    public String getOneString(String sql, ParameterSetter parameter) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneString(sql, parameter);
        }finally{
            conn.close();
        }
    }

    public String getOneString(String sql, ParameterSetter[] parameters) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneString(sql, parameters);
        }finally{
            conn.close();
        }
    }

    public String getOneString(String sql, List<ParameterSetter> parameters) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneString(sql, parameters);
        }finally{
            conn.close();
        }
    }

    public int getOneInt(String sql) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneInt(sql);
        }finally{
            conn.close();
        }
    }

    public int getOneInt(String sql, ParameterSetter parameter) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneInt(sql, parameter);
        }finally{
            conn.close();
        }
    }

    public int getOneInt(String sql, ParameterSetter[] parameters) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneInt(sql, parameters);
        }finally{
            conn.close();
        }
    }

    public int getOneInt(String sql, List<ParameterSetter> parameters) throws SQLException
    {
        EZSQLConnection conn = new EZSQLConnection(connectionFactory.getConnection());
        try {
            return conn.getOneInt(sql, parameters);
        }finally{
            conn.close();
        }
    }
}
