package net.rumati.ezsql;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.LinkedList;
import java.util.List;

public abstract class ResultSetHandler<E>
{
    public abstract E handleResultSet(ResultSet rs)
            throws SQLException;

    public static <T> ResultSetHandler<T> getFirstRow(final RowHandler<T> h)
    {
        return new ResultSetHandler<T>() {
            @Override
            public T handleResultSet(ResultSet rs)
                    throws SQLException
            {
                if (!rs.next()){
                    return null;
                }
                return h.handleRow(new Row(rs));
            }
        };
    }

    public static <T> ResultSetHandler<List<T>> getAllRows(final RowHandler<T> h)
    {
        return new ResultSetHandler<List<T>>() {
            @Override
            public List<T> handleResultSet(ResultSet rs)
                    throws SQLException
            {
                List<T> retv = new LinkedList<T>();
                Row r = new Row(rs);
                while (rs.next()){
                    retv.add(h.handleRow(r));
                }
                return retv;
            }
        };
    }

}
